@@ -10,7 +10,7 @@
 
 
 from meutils.pipe import *
-from meutils.apis.proxy import ips
+from meutils.apis.proxy import kdlapi
 
 from gradio_client import Client, handle_file as _handle_file
 
@@ -19,9 +19,9 @@ handle_file = lru_cache()(_handle_file)
 async def create_client(endpoint, hf_token: Optional[str]=None, with_proxies: bool = False):
     httpx_kwargs = None
     if with_proxies:  # 无法使用
-        proxies = await ips.get_proxies()
+        proxy = await kdlapi.get_one_proxy()
         httpx_kwargs = {
-            "proxies": proxies,
+            "proxy": proxy,
         }
 
     client = Client(
@@ -32,3 +32,4 @@ async def create_client(endpoint, hf_token: Optional[str]=None, with_proxies: bo
     )
 
     return client
+
