@@ -10,6 +10,11 @@
 
 from meutils.pipe import *
 
+"""
+        "message": "{\"error\":{\"code\":\"\",\"message\":\"所有令牌分组 default 下对于模型 fal-minimax-voice-clone_minimax-_6s_720p 均无可用渠道，请更换分组尝试 (request id: 20250913110021793629462u1r59kQ8)\",\"type\":\"rix_api_error\"}}",
+
+"""
+
 
 def make_billing_model(model: str, request: dict):
     """
@@ -32,7 +37,7 @@ def make_billing_model(model: str, request: dict):
 
         return f"{model}_{billing_model}"
 
-    elif _model.startswith(("minimax-speech",)):  # 按量跳过
+    elif _model.startswith(("minimax-speech", "minimax-voice")):  # 按量跳过
         return
 
 
