@@ -90,6 +90,7 @@ async def create_task(request: Union[CompletionRequest, VideoRequest, SoraVideoR
         ttl=24 * 3600,
         check_token=check_token_for_volc
     )
+    logger.debug(request)
 
     logger.debug(f"api_key: {api_key}")
     if isinstance(request, SoraVideoRequest):  # todo 首尾帧 参考图
@@ -109,8 +110,7 @@ async def create_task(request: Union[CompletionRequest, VideoRequest, SoraVideoR
                     }
                 ]
             }
-            if request.input_reference:
-                images = await to_base64(request.input_reference)
+            if images := request.input_reference:
                 if len(images) > 2:
                     images = images[:2]
 
