@@ -588,6 +588,12 @@ def url2fileview(url):
     return f"https://v.ffire.cc/onlinePreview?url={encoded_url}"
 
 
+def any2log(*objs, threshold: int = 1000):
+    for obj in objs:
+        if len(str(obj)) < threshold:
+            logger.debug(obj)
+
+
 if __name__ == '__main__':
     pass
     # s = "import pandas as pd; output = pd.__version__"
@@ -613,4 +619,7 @@ if __name__ == '__main__':
 
     pass
 
+    # any2log("request")
 
+    any2log(["request"] * 10)
+    any2log("reques", "request2")
