@@ -449,7 +449,7 @@ async def check_token_for_runware(api_key, threshold: float = 5):
         balance = data['data'][0]['balance']
         logger.debug(balance)
 
-        return balance > threshold
+        return balance >= threshold
 
     except TimeoutException as e:
         raise
