@@ -31,8 +31,9 @@ async def chat_for_image(
         request: CompletionRequest,
         api_key: Optional[str] = None,
         base_url: Optional[str] = None,
+        http_client: Optional[Any] = None,
 ):
-    generate = generate and partial(generate, api_key=api_key, base_url=base_url)
+    generate = generate and partial(generate, api_key=api_key, base_url=base_url, http_client=http_client)
 
     image = None
     prompt = request.last_user_content
