@@ -59,7 +59,7 @@ ASPECT_RATIOS = {
 
 
 class ImagesResponse(_ImagesResponse):
-    created: int = Field(default_factory=lambda: int(time.time()))
+    created: Optional[int] = Field(default_factory=lambda: int(time.time()))
 
     data: Optional[List[Union[Image, dict]]] = []
 
@@ -71,6 +71,8 @@ class ImagesResponse(_ImagesResponse):
 
     def __init__(self, /, **data: Any):
         super().__init__(**data)
+        self.created = self.created or int(time.time())
+
         if not self.data and self.image is not None:
             if isinstance(self.image, str):
                 self.image = [self.image]
@@ -156,7 +158,7 @@ class ImageRequest(BaseModel):  # openai
                 self.aspect_ratio = size2aspect_ratio(self.size)
                 self.size = self.size if 'x' in self.size else '512x512'
 
-        if not self.resolution and '_' in self.model and self.model.endswith('k'):  # _4k
+        if not self.resolution and '_' in self.model and self.model.lower().endswith('k'):  # _4k
             self.model, self.resolution = self.model.rsplit('_', maxsplit=1)
 
     @cached_property
@@ -194,6 +196,18 @@ class ImageRequest(BaseModel):  # openai
             if aspect_ratio in self.prompt:
                 return aspect_ratio
 
+    @cached_property
+    def cmdprompt(self):
+        if self.aspect_ratio:
+            self.prompt += f" --aspect_ratio {self.aspect_ratio}"
+        elif self.size:
+            self.prompt += f" --size {self.size}"
+
+        if self.resolution:
+            self.prompt += f" --resolution {self.resolution}"
+
+        return self.prompt
+
     class Config:
         extra = "allow"
 
@@ -210,7 +224,7 @@ class ImageRequest(BaseModel):  # openai
         }
 
 
-class ImageEditRequest(BaseModel):
+class ImageEditRequest(BaseModel):  # todo 继承 ImageRequest
     model: Union[str, Literal["dall-e-2", "dall-e-3", "gpt-image-1"]]
 
     # image: Union[FileTypes, SequenceNotStr[FileTypes]],
@@ -237,6 +251,7 @@ class ImageEditRequest(BaseModel):
 
     response_format: Optional[Literal["url", "b64_json"]] = None
     output_format: Optional[Literal["png", "jpeg", "webp"]] = None
+    resolution: Optional[str] = None  # 1k 2k 4k
 
     # output_compression: Optional[int] | NotGiven = NOT_GIVEN,
     # partial_images: Optional[int] | NotGiven = NOT_GIVEN,
@@ -748,3 +763,14 @@ if __name__ == '__main__':
     )
 
     # print(_)
+
+    # ImageEditRequest(
+    #     model="model",
+    #     size=None,
+    #     prompt="带个墨镜",
+    #     image=["https://s3.ffire.cc/files/jimeng.jpg"],
+    #     resolution='xx',
+    #     image_url="https://s3.ffire.cc/files/jimeng.jpg",
+    # )
+
+    print(ImagesResponse(data=[{'url': 1}], created=None))
